# Load packages ----------------------------------------------------------------
library (tidyverse)
library (corrplot)
library (skimr)
library (MASS)
library (bootStepAIC)
library(correlation)
library(gtsummary)
library(labelled)
library(flextable)
library (officer)

# Import data ------------------------------------------------------------------
df2 <- readRDS("output/df2_mod.RDS")

# Hypothesis ONE ---------------------------------------------------------------

t.test(df2$phoda, mu=19, alternative = c("two.sided"))
t.test(df2$bpaq, mu=113, alternative = c("two.sided"))


t.test(df2$phoda ~ factor (df2$sex), mu=0, na.action = na.omit)
t.test(df2$bpaq ~ factor (df2$sex), mu=0, na.action = na.omit)

## Exploratory
t.test(df2$phoda[df2$sex == 1], mu=19, alternative = c("two.sided"))
t.test(df2$phoda[df2$sex == 2], mu=19, alternative = c("two.sided"))

# Hypothesis TWO ---------------------------------------------------------------

cor.test(df2$bpaq, df2$phoda)

# Hypothesis THREE--------------------------------------------------------------

# Subset data for complete -----------------------------------------------------

## Include the training load lifted
df8 <- df2 %>%
  dplyr::select (mass_train, bpaq, phoda, age, sex, starts_with("oslo"),
                 sport_train, sport_com, years_train, pain_intense,
                 train_dead_wt, train_back_wt) %>%
  mutate_at (vars(matches("_wt")), ~ (.x/mass_train) * 100) %>%
  mutate_at(vars(matches("oslo")), ~ifelse (.x <=1, 0, 1)) %>%
  mutate_at(vars("sex":"years_train"), as.factor) %>%
  mutate(pain_intense = as.numeric (pain_intense))


# Impute

imp <- mice::mice(df8, m = 5, seed = 155, maxit = 30, meth = "rf")
# saveRDS(imp, "output/imp.RDS")
#
# imp <- readRDS("output/imp.RDS")

set.seed((265))
rand_n <- sample(1:5, 1)

df9 <- complete(imp, rand_n)

df9 <- df9 %>%
  mutate_at(vars(age, pain_intense, train_dead_wt, train_back_wt),
            scale, center = TRUE, scale = TRUE) %>%
  dplyr::select (-mass_train)

correlation::correlation (df9)

# StepAIC ---------------------------------------------------------------------

# res <- readRDS("output/res.RDS")
# m.boot <- res$phoda_mod
# m.boot2 <- res$bpaq_mod

## PHODA as outcome
dat <- df9 %>% dplyr::select (-bpaq, -pain_intense, -train_dead_wt)

## Original lm model
m <- lm (phoda ~., data = dat)

## Bootstrap to get stability
m.boot <- boot.stepAIC (object = m,
                        data = dat,
                        direction = "both",
                        B = 1000 ,
                        alpha = 0.05,
                        seed = 123)
m.boot
summary (m.boot$OrigStepAIC)

performance::check_model(m.boot$OrigModel)

resz <- rstandard(m.boot$OrigModel)

#create Q-Q plot for residuals
qqnorm(resz)

#add a straight diagonal line to the plot
qqline(resz)

## assumptions check

performance::check_model(m.boot$OrigStepAIC)

#Regression tables

regress1 <- tbl_regression(m.boot$OrigStepAIC,
               list(age ~ "Age",
                    oslo_2 ~ "Oslo Q2",
                    oslo_4 ~ "Oslo Q4",
                    years_train ~ "Years Train",
                    train_back_wt ~ "Back Squat Weight (kg)"),
               intercept = TRUE
               ) %>%
               bold_labels() %>%
  modify_header(label = "**Variable**") %>%
  bold_p() %>%
  remove_row_type(0, type = "header")

## BPAQ as outcome

dat2 <-  df9 %>% dplyr::select (-phoda, -pain_intense, -train_dead_wt)

## Original lm model
m <- lm (bpaq ~., data = dat2)

## Bootstrap to get stability
m.boot2 <- boot.stepAIC (object = m,
                        data = dat2,
                        direction = "both",
                        B = 1000 ,
                        alpha = 0.05,
                        seed = 123)
m.boot2
summary (m.boot2$OrigStepAIC)

## assumptions check

performance::check_model(m.boot2$OrigModel)

resz <- rstandard(m.boot2$OrigModel)

#create Q-Q plot for residuals
qqnorm(resz)

#add a straight diagonal line to the plot
qqline(resz)
#Regression tables

regress2 <- tbl_regression(m.boot2$OrigStepAIC,
               list(age ~ "Age",
                    oslo_1 ~ "Oslo Q1",
                    oslo_4 ~ "Oslo Q4",
                    train_back_wt ~ "Back Squat Weight (kg)"),
               intercept = TRUE) %>%
                bold_labels() %>%
                modify_header(label = "**Variable**") %>%
                bold_p() %>%
                remove_row_type(0, type = "header")

res <- list (phoda_mod = m.boot,
             bpaq_mod = m.boot2)

saveRDS(res, "output/res.RDS")

# Reporting --------------------------------------------------------------------

## Table 1 ---------------------------------------------------------------------

facs <- c("sex",
          "years_train",
          "days_train",
          "period_train",
          "sport_train",
          "sport_com",
          "oslo_1",
          "oslo_2",
          "oslo_3",
          "oslo_4")

df4 <- df2 %>%
  mutate (oslo_1 = factor (oslo_1, levels = c("1", "2", "3", "4"),
                           labels = c("Full participation without low back problems",
                                      "Full participation with low back problems",
                                      "Reduced participation due to low back problems",
                                      "Cannot participate due to low back problems")),
          oslo_2 = factor (oslo_2, levels = c("1", "2", "3", "4", "5"),
                           labels = c("No reduction",
                                      "To a minor extent",
                                      "To a moderate extent",
                                      "To a major extent",
                                      "Cannot participate at all")),
          oslo_3 = factor (oslo_3, levels = c("1", "2", "3", "4", "5"),
                           labels = c("No effect",
                                      "To a minor extent",
                                      "To a moderate extent",
                                      "To a major extent",
                                      "Cannot participate at all")),
          oslo_4 = factor (oslo_4, levels = c("1", "2", "3", "4"),
                           labels = c("No pain",
                                      "Mild pain",
                                      "Moderate pain",
                                      "Severe pain"))) %>%
  mutate_at (facs, factor) %>%
  mutate(sex = factor (sex, labels = c("Male", "Female")),
         years_train = factor (years_train, labels = c("<1yr", "1-3yrs", "3-5yrs", ">5yrs")),
         days_train = fct_collapse(days_train,
                                   "1" = c("2", "3", "4"),
                                   "2" = c("5"),
                                   "3" = c("6", "7")),
         days_train = factor (days_train, labels = c("1-4d", "5d", "6-7d")),
         period_train = factor (period_train, labels = c("<1hr", "1-2hr", ">2hr")),
         sport_train = factor (sport_train, labels = c("WL only", "PL only", "WL+PL")),
         sport_com = factor (sport_com, labels = c("None", "WL", "PL"))
         )


new_head <- c("Age (yrs)",
              "Sex",
              "Height (m)",
              "Body mass (kg)",
              "Years of training",
              "Frequency of training (days/week)",
              "Session duration (hrs)",
              "Training sport",
              "Competition sport",
              "1RM Deadlift (kg)",
              "1RM Back Squat (kg)",
              "Back-PAQ",
              "PHODA-SeV",
              "Oslo - 1",
              "Oslo - 2",
              "Oslo - 3",
              "Oslo - 4",
              "Pain intensity")

names(df4) <- new_head


descrb_df <- df4 %>%
  tbl_summary(
    statistic = list(all_continuous() ~ "{mean} ({sd})",
                     all_categorical() ~ "{n} / {N} ({p}%)"),
    missing_text = "Missing",
    digits = list(all_continuous() ~ c(2,2))) %>%
  bold_labels() %>%
  modify_header(label = "**Variable**") %>%
  #remove_row_type(type = "missing") %>%
  as_flex_table()

descrb_df


my_path <- paste0("../paper/table1",
                  ".docx")

ft <- descrb_df %>%
  set_caption(caption = "Table 1") %>%
  autofit()

my_doc <- read_docx()  %>%
  body_add_flextable(ft)

print (my_doc, target = my_path)

## Table 2 ---------------------------------------------------------------------

regress1 <- regress1 %>%
  as_flex_table()

my_path <- paste0("../paper/table2",
                  ".docx")

ft <- regress1 %>%
  set_caption(caption = "Table 2") %>%
  autofit()

my_doc <- read_docx()  %>%
  body_add_flextable(ft)

print (my_doc, target = my_path)

## Table 3 ---------------------------------------------------------------------

regress2 <- regress2 %>%
  as_flex_table()

my_path <- paste0("../paper/table3",
                  ".docx")

ft <- regress2 %>%
  set_caption(caption = "Table 3") %>%
  autofit()

my_doc <- read_docx()  %>%
  body_add_flextable(ft)

print (my_doc, target = my_path)

## Table 4 ---------------------------------------------------------------------

cov_df1 <- data.frame (Covariates = row.names(m.boot$Covariates),
                      Phoda = m.boot$Covariates[,1])

cov_df2 <- data.frame (Covariates = row.names(m.boot2$Covariates),
                      BackPAQ = m.boot2$Covariates[,1])

cov_df <- cov_df1 %>%
  inner_join(cov_df2, by = "Covariates")


my_path <- paste0("../paper/table4",
                  ".docx")

ft <- flextable (cov_df) %>%
  set_caption(caption = "Table 4") %>%
  autofit()

my_doc <- read_docx()  %>%
  body_add_flextable(ft)

print (my_doc, target = my_path)


# Figure 1 ---------------------------------------------------------------------

df3 <- df2 %>%
  dplyr::select (mass_train, bpaq, phoda, age, sex, starts_with("oslo"),
                 sport_train, sport_com, years_train, pain_intense,
                 train_dead_wt, train_back_wt) %>%
  mutate_at (vars(matches("_wt")), ~ (.x/mass_train) * 100) %>%
  mutate_at(vars(matches("oslo")), ~ifelse (.x <=1, 0, 1))%>%
  mutate_at(vars("sex":"oslo_4"), as.factor) %>%
  mutate(pain_intense = as.numeric (pain_intense))


df.plot <- df3 %>%
  group_by(sex) %>%
  summarize (Mean = mean (bpaq),
             Sd = sd (bpaq))


f1 <- ggplot () +
  geom_bar (data = df.plot,
            aes (x = sex, y = Mean), fill = "white", color = "black", stat = "identity", width = 0.5) +
  geom_errorbar(data = df.plot,
                aes (x = sex, ymin = Mean - Sd, ymax = Mean + Sd), color = "black", width = 0.05, size= 2) +
  geom_point (data = df3,
              aes(x = sex, y = bpaq), color = "red", size = 0.5) +
  geom_hline(yintercept = 113, linetype = 2) +
  ylab ("Back-PAQ Score") +
  xlab ("Sex") +
  scale_x_discrete(labels=c("Male", "Female")) +
  cowplot::theme_cowplot()


df.plot <- df3 %>%
  group_by(sex) %>%
  summarize (Mean = mean (phoda),
             Sd = sd (phoda))


f2 <- ggplot () +
  geom_bar (data = df.plot,
            aes (x = sex, y = Mean), fill = "white", color = "black", stat = "identity", width = 0.5) +
  geom_errorbar(data = df.plot,
                aes (x = sex, ymin = Mean - Sd, ymax = Mean + Sd), color = "black", width = 0.05, size= 2) +
  geom_point (data = df3,
              aes(x = sex, y = phoda), color = "red", size = 0.5) +
  geom_hline(yintercept = 19, linetype = 2) +
  ylab ("PHODA-SeV Score") +
  xlab ("Sex") +
  scale_x_discrete(labels=c("Male", "Female")) +
  cowplot::theme_cowplot()

tiff ("../paper/fig1.tiff", height = 5, width = 7, units = "in", res = 100)
cowplot::plot_grid(f2, f1)
dev.off()
